// ============================================================================
// Artsoft Retro-Game Library
// ----------------------------------------------------------------------------
// (c) 1995-2014 by Artsoft Entertainment
//     		    Holger Schemel
//		    info@artsoft.org
//		    https://www.artsoft.org/
// ----------------------------------------------------------------------------
// libgame.h
// ============================================================================

#ifndef LIBGAME_H
#define LIBGAME_H

#define LIBGAME_VERSION_1_0_0

#include "platform.h"
#include "types.h"
#include "system.h"
#include "random.h"
#include "gadgets.h"
#include "text.h"
#include "sound.h"
#include "snapshot.h"
#include "joystick.h"
#include "image.h"
#include "setup.h"
#include "misc.h"
#include "http.h"
#include "base64.h"
#include "zip/miniunz.h"

#endif // LIBGAME_H
